@@ -17,3 +17,13 @@ class Lorenz(_Differential):
         z_dot = x*y - b*z
 
         return x_dot, y_dot, z_dot
+
+    def jacobian(self):
+        s, r, b = self.s, self.r, self.b
+        x, y, z = self.u
+
+        j = [[-s, s, 0],
+             [r-z, -1, -x],
+             [y, x, -b]]
+
+        return j
